aboutsummaryrefslogtreecommitdiffstats
path: root/src/construct/mod.rs
diff options
context:
space:
mode:
authorLibravatar Titus Wormer <tituswormer@gmail.com>2022-06-21 17:24:56 +0200
committerLibravatar Titus Wormer <tituswormer@gmail.com>2022-06-21 17:24:56 +0200
commit56ff5c73c7ec19b349e7d60d04ce1057c006d6ec (patch)
treeb4107ae0e0219f871a2f2764215ad979b2b0d75f /src/construct/mod.rs
parent7effd171218fff68f051671f1373cee467a8f921 (diff)
downloadmarkdown-rs-56ff5c73c7ec19b349e7d60d04ce1057c006d6ec.tar.gz
markdown-rs-56ff5c73c7ec19b349e7d60d04ce1057c006d6ec.tar.bz2
markdown-rs-56ff5c73c7ec19b349e7d60d04ce1057c006d6ec.zip
Make data a construct
Diffstat (limited to 'src/construct/mod.rs')
-rw-r--r--src/construct/mod.rs20
1 files changed, 15 insertions, 5 deletions
diff --git a/src/construct/mod.rs b/src/construct/mod.rs
index 407dc6b..9e5da0e 100644
--- a/src/construct/mod.rs
+++ b/src/construct/mod.rs
@@ -7,11 +7,10 @@
//! For example, [code (fenced)][code_fenced] and
//! [code (indented)][code_indented] are considered different constructs
//!
//! <!-- To do: can these rest things be made into constructs? -->
//!
//! Content types also have a *rest* thing: after all character escapes and
//! character references are parsed, there’s something left.
//! This remainder is, currently, not called a constructs.
//!
//! The following constructs are found in markdown:
//!
@@ -38,6 +37,14 @@
//! * [paragraph][]
//! * [thematic break][thematic_break]
//!
+//! There are also several routines used in different places:
+//!
+//! * [data][partial_data]
+//! * [destination][partial_destination]
+//! * [label][partial_label]
+//! * [space or tab][partial_space_or_tab]
+//! * [title][partial_title]
+//!
//! Each construct maintained here is explained with a BNF diagram.
//! For example, the docs for [character escape][character_escape] contain:
//!
@@ -52,6 +59,8 @@
//! They also contain references to character as defined by [char][], so for
//! example `ascii_punctuation` refers to
//! [`char::is_ascii_punctuation`][char::is_ascii_punctuation].
+//!
+//!
pub mod autolink;
pub mod blank_line;
@@ -68,6 +77,7 @@ pub mod heading_setext;
pub mod html_flow;
pub mod html_text;
pub mod paragraph;
+pub mod partial_data;
pub mod partial_destination;
pub mod partial_label;
pub mod partial_space_or_tab;
@@ -7,11 +7,10 @@
//! [code (indented)][code_indented] are considered different constructs
//!
-//! <!-- To do: can these rest things be made into constructs? -->
-//!
-//! Content types also have a *rest* thing: after all character escapes and
-//! character references are parsed, there’s something left.
-//! This remainder is, currently, not called a constructs.
+//! Content types also have a *rest* thing: after all things are parsed,
+//! there’s something left.
+//! In flow, that is a [paragraph][].
+//! In string and text, that is [data][partial_data].
//!
//! The following constructs are found in markdown: